##  Filtering Fact Sheets
When SAP LeanIX is selected as the source, a filter icon appears in the Actions column of the mapping row, allowing you to filter the fact sheets that should be mapped to dictionary items.
Filtering lets you narrow down your focus and helps you better organize and structure your data. For example, you can filter and group applications from different departments into separate dictionary categories or separate active applications from those that are phased out, ensuring only active applications are used while designing processes. Learn more about best practices for managing lifecycle phases in [Managing Application Lifecycles in SAP Signavio](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758ecda7a4410148fc2e2c4b70df0d1__managing_application_lifecycles_in_sap_signavio).
